/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2012 University of Bonn. All rights reserved.
 * Please see the LICENSE file or "Copyright notice" in builder.cpp for details.
 */

/*
 * CommandLineDialog.cpp
 *
 *  Created on: May 8, 2010
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "CommandLineUI/CommandLineDialog.hpp"
#include "CommandLineUI/Query/CommandLineQuery.hpp"


using namespace std;


CommandLineDialog::CommandLineDialog()
{
}

CommandLineDialog::~CommandLineDialog()
{
}


void CommandLineDialog::queryEmpty(const char* title, std::string _description){
  registerQuery(new EmptyCommandLineQuery(title, _description));
}

void CommandLineDialog::queryInt(Parameter<int> &param, const char* title, std::string _description){
  registerQuery(new IntCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryInts(Parameter<std::vector<int> > &param, const char* title, std::string _description){
  registerQuery(new IntsCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryUnsignedInt(Parameter<unsigned int> &param, const char* title, std::string _description){
  registerQuery(new UnsignedIntCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryUnsignedInts(Parameter<std::vector<unsigned int> > &param, const char* title, std::string _description){
  registerQuery(new UnsignedIntsCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryBoolean(Parameter<bool> &param, const char* title, std::string _description){
  registerQuery(new BooleanCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryDouble(Parameter<double> &param, const char* title, std::string _description){
  registerQuery(new DoubleCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryDoubles(Parameter<std::vector<double> > &param, const char* title, std::string _description){
  registerQuery(new DoublesCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryString(Parameter<std::string> &param, const char* title, std::string _description){
  registerQuery(new StringCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryStrings(Parameter<std::vector<std::string> > &param, const char* title, std::string _description){
  registerQuery(new StringsCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryAtom(Parameter<const atom *> &param, const char* title, std::string _description) {
  registerQuery(new AtomCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryAtoms(Parameter<std::vector<const atom *> > &param, const char* title, std::string _description) {
  registerQuery(new AtomsCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryMolecule(Parameter<const molecule *> &param, const char* title, std::string _description) {
  registerQuery(new MoleculeCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryMolecules(Parameter<std::vector<const molecule *> > &param, const char* title, std::string _description) {
  registerQuery(new MoleculesCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryVector(Parameter<Vector> &param, const char* title, bool check, std::string _description) {
  registerQuery(new VectorCommandLineQuery(param, title,check, _description));
}

void CommandLineDialog::queryVectors(Parameter<std::vector<Vector> > &param, const char* title, bool check, std::string _description) {
  registerQuery(new VectorsCommandLineQuery(param, title,check, _description));
}

void CommandLineDialog::queryBox(Parameter<Box> &param, const char* title, std::string _description) {
  registerQuery(new BoxCommandLineQuery(param, title,_description));
}

void CommandLineDialog::queryElement(Parameter<const element *> &param, const char* title, std::string _description){
  registerQuery(new ElementCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryElements(Parameter<std::vector<const element *> > &param, const char* title, std::string _description){
  registerQuery(new ElementsCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryFile(Parameter<boost::filesystem::path> &param, const char* title, std::string _description){
  registerQuery(new FileCommandLineQuery(param, title, _description));
}

void CommandLineDialog::queryRandomNumberDistribution_Parameters(Parameter<RandomNumberDistribution_Parameters> &param, const char* title, std::string _description){
  registerQuery(new RandomNumberDistribution_ParametersCommandLineQuery(param, title, _description));
}

/************************** Query Infrastructure ************************/
/*       ---> shifted to folder Query                                   */
/************************************************************************/
